==> elo_indexserver_client-0.1.2.tar.gz: elo_indexserver_client-0.1.2/eloclient/models/b_request_ix_service_port_if_find_first_activities.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.activity_z import ActivityZ
    from ..models.client_info import ClientInfo
    from ..models.find_activity_info import FindActivityInfo


T = TypeVar("T", bound="BRequestIXServicePortIFFindFirstActivities")


@_attrs_define
class BRequestIXServicePortIFFindFirstActivities:
    """
    Attributes:
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface function, except the
             login, requires a <code>ClientInfo</code> object as parameter with a valid session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        find_info (Union[Unset, FindActivityInfo]): This class specifies constraints for the API function
            {@link IXServicePortIF#findFirstActivities(ClientInfo, FindActivityInfo, int, ActivityZ)}.
             <p>
             By default, the members of this class are combined by AND. If {@link #senderOrReceiver} is set, senderId and
             receiverId are combined by OR.
             </p>
             <p>
             If neither senderId nor receiverId is set, the function findFirstActivities collects all activities that can be
            read
             by the current session.
             </p>
        max_ (Union[Unset, int]):
        activity_z (Union[Unset, ActivityZ]): Typed element selector for class Activity.
    """

    ci: Union[Unset, "ClientInfo"] = UNSET
    find_info: Union[Unset, "FindActivityInfo"] = UNSET
    max_: Union[Unset, int] = UNSET
    activity_z: Union[Unset, "ActivityZ"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        find_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.find_info, Unset):
            find_info = self.find_info.to_dict()

        max_ = self.max_
        activity_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.activity_z, Unset):
            activity_z = self.activity_z.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ci is not UNSET:
            field_dict["ci"] = ci
        if find_info is not UNSET:
            field_dict["findInfo"] = find_info
        if max_ is not UNSET:
            field_dict["max"] = max_
        if activity_z is not UNSET:
            field_dict["activityZ"] = activity_z

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.activity_z import ActivityZ
        from ..models.client_info import ClientInfo
        from ..models.find_activity_info import FindActivityInfo

        d = src_dict.copy()
        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        _find_info = d.pop("findInfo", UNSET)
        find_info: Union[Unset, FindActivityInfo]
        if isinstance(_find_info, Unset):
            find_info = UNSET
        else:
            find_info = FindActivityInfo.from_dict(_find_info)

        max_ = d.pop("max", UNSET)

        _activity_z = d.pop("activityZ", UNSET)
        activity_z: Union[Unset, ActivityZ]
        if isinstance(_activity_z, Unset):
            activity_z = UNSET
        else:
            activity_z = ActivityZ.from_dict(_activity_z)

        b_request_ix_service_port_if_find_first_activities = cls(
            ci=ci,
            find_info=find_info,
            max_=max_,
            activity_z=activity_z,
        )

        b_request_ix_service_port_if_find_first_activities.additional_properties = d
        return b_request_ix_service_port_if_find_first_activities

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> elo_indexserver_client-0.1.30.tar.gz: elo_indexserver_client-0.1.30/eloclient/models/b_request_ix_service_port_if_find_first_activities.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.activity_z import ActivityZ
    from ..models.client_info import ClientInfo
    from ..models.find_activity_info import FindActivityInfo


T = TypeVar("T", bound="BRequestIXServicePortIFFindFirstActivities")


@_attrs_define
class BRequestIXServicePortIFFindFirstActivities:
    """
    Attributes:
        max_ (Union[Unset, int]):
        ci (Union[Unset, ClientInfo]): Contains the session ticket and the users language and country.
            Each Indexserver interface
             function, except the login, requires a <code>ClientInfo</code> object as parameter with a valid
             session ticket.
             <p>
             Copyright: Copyright (c) 2004
             </p>
             <p>
             Organisation: ELO Digital Office GmbH
             </p>
        find_info (Union[Unset, FindActivityInfo]): This class specifies constraints for the API function
            {@link IXServicePortIF#findFirstActivities(ClientInfo, FindActivityInfo, int, ActivityZ)}.
             <p>
             By default, the members of this class are combined by AND. If {@link #senderOrReceiver} is set,
             senderId and receiverId are combined by OR.
             </p>
             <p>
             If neither senderId nor receiverId is set, the function findFirstActivities collects all
             activities that can be read by the current session.
             </p>
        activity_z (Union[Unset, ActivityZ]): Typed element selector for class Activity.
    """

    max_: Union[Unset, int] = UNSET
    ci: Union[Unset, "ClientInfo"] = UNSET
    find_info: Union[Unset, "FindActivityInfo"] = UNSET
    activity_z: Union[Unset, "ActivityZ"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        max_ = self.max_

        ci: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ci, Unset):
            ci = self.ci.to_dict()

        find_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.find_info, Unset):
            find_info = self.find_info.to_dict()

        activity_z: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.activity_z, Unset):
            activity_z = self.activity_z.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if max_ is not UNSET:
            field_dict["max"] = max_
        if ci is not UNSET:
            field_dict["ci"] = ci
        if find_info is not UNSET:
            field_dict["findInfo"] = find_info
        if activity_z is not UNSET:
            field_dict["activityZ"] = activity_z

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.activity_z import ActivityZ
        from ..models.client_info import ClientInfo
        from ..models.find_activity_info import FindActivityInfo

        d = src_dict.copy()
        max_ = d.pop("max", UNSET)

        _ci = d.pop("ci", UNSET)
        ci: Union[Unset, ClientInfo]
        if isinstance(_ci, Unset):
            ci = UNSET
        else:
            ci = ClientInfo.from_dict(_ci)

        _find_info = d.pop("findInfo", UNSET)
        find_info: Union[Unset, FindActivityInfo]
        if isinstance(_find_info, Unset):
            find_info = UNSET
        else:
            find_info = FindActivityInfo.from_dict(_find_info)

        _activity_z = d.pop("activityZ", UNSET)
        activity_z: Union[Unset, ActivityZ]
        if isinstance(_activity_z, Unset):
            activity_z = UNSET
        else:
            activity_z = ActivityZ.from_dict(_activity_z)

        b_request_ix_service_port_if_find_first_activities = cls(
            max_=max_,
            ci=ci,
            find_info=find_info,
            activity_z=activity_z,
        )

        b_request_ix_service_port_if_find_first_activities.additional_properties = d
        return b_request_ix_service_port_if_find_first_activities

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
